==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/ai/goal/work/NPCBreedGoal.java <==
package cc.thonly.reverie_dreams.entity.ai.goal.work;

import cc.thonly.reverie_dreams.entity.ai.goal.util.EntityTargetUtil;
import cc.thonly.reverie_dreams.entity.npc.NPCEntityImpl;
import cc.thonly.reverie_dreams.entity.npc.NPCState;
import cc.thonly.reverie_dreams.entity.npc.NPCStates;
import cc.thonly.reverie_dreams.entity.npc.NPCWorkModes;
import cc.thonly.reverie_dreams.interfaces.IAnimalEntity;
import lombok.Getter;
import net.minecraft.class_1268;
import net.minecraft.class_1309;
import net.minecraft.class_1352;
import net.minecraft.class_1405;
import net.minecraft.class_1429;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_3218;
import net.minecraft.class_4051;
import org.jetbrains.annotations.Nullable;

import java.util.EnumSet;
import java.util.List;

@Getter
public class NPCBreedGoal extends class_1405 {
    private final NPCEntityImpl maid;
    private final class_4051 targetPredicate = class_4051.method_36625().method_18418(16).method_18420((e, w) -> {
        return !e.method_16914();
    });
    @Nullable
    private Runnable task;
    private class_1429 targetEntity;

    public NPCBreedGoal(NPCEntityImpl maid) {
        super(maid, false);
        this.maid = maid;
        this.method_6265(EnumSet.of(class_1352.class_4134.field_18408));
    }

    @Override
    public boolean method_6264() {
        if (!this.maid.method_6181() || this.maid.method_24345()) {
            return false;
        }
        NPCState state = maid.getNpcState();
        class_1309 owner = this.maid.method_35057();
        if (owner == null || state != NPCStates.WORKING || maid.getWorkMode() != NPCWorkModes.BREED) {
            return false;
        }
        class_2338 workPos = maid.getWorkingPos();
        class_3218 serverWorld = method_64451(maid);

        List<class_1429> targets = this.field_6660.method_37908().method_8390(class_1429.class, new class_238(workPos).method_1009(16, 8, 16), (e) -> {
            boolean alive = e.method_5805();
            boolean hasItem = e.method_6481(this.maid.method_5998(class_1268.field_5808));
            int i = e.method_5618();
            if (i == 0 && e.method_6482() && !e.method_6109()) {
                return alive && hasItem;
            }
            return false;
        });
        this.targetEntity = serverWorld.method_64393(targets, this.targetPredicate, this.maid, this.maid.method_23317(), this.maid.method_23320(), this.maid.method_23321());
        return this.targetEntity != null;
    }

    @Override
    public void method_6269() {
        this.task = ()-> {
            ((IAnimalEntity)this.targetEntity).eatStackFood(this.maid, class_1268.field_5808, this.maid.method_5998(class_1268.field_5808));
            this.targetEntity.method_61458();
            ((IAnimalEntity)this.targetEntity).loveEntity(this.maid);
        };
    }

    @Override
    public void method_6268() {
        if (this.task == null) {
            return;
        }
        if (this.targetEntity != null && this.targetEntity.method_5805()) {
            this.maid.method_5942().method_6335(this.targetEntity, 1.0D);

            if (this.maid.method_5858(this.targetEntity) <= 4.0D) {
                this.task.run();
                this.task = null;
                this.method_6270();
            }
        }
    }

}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/ai/goal/work/NPCBreedGoal.java <==
package cc.thonly.reverie_dreams.entity.ai.goal.work;

import cc.thonly.reverie_dreams.entity.npc.BaseNPCLikeEntity;
import cc.thonly.reverie_dreams.data.npc.NPCState;
import cc.thonly.reverie_dreams.registry.content.NPCStates;
import cc.thonly.reverie_dreams.registry.content.NPCWorkModes;
import cc.thonly.reverie_dreams.interfaces.IAnimalEntity;
import lombok.Getter;
import net.minecraft.class_1268;
import net.minecraft.class_1309;
import net.minecraft.class_1352;
import net.minecraft.class_1405;
import net.minecraft.class_1429;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_3218;
import net.minecraft.class_4051;
import org.jetbrains.annotations.Nullable;

import java.util.EnumSet;
import java.util.List;

@Getter
public class NPCBreedGoal extends class_1405 {
    private final BaseNPCLikeEntity maid;
    private final class_4051 targetPredicate = class_4051.method_36625().method_18418(16).method_18420((e, w) -> {
        return !e.method_16914();
    });
    @Nullable
    private Runnable task;
    private class_1429 targetEntity;

    public NPCBreedGoal(BaseNPCLikeEntity maid) {
        super(maid, false);
        this.maid = maid;
        this.method_6265(EnumSet.of(class_1352.class_4134.field_18408));
    }

    @Override
    public boolean method_6264() {
        if (!this.maid.method_6181() || this.maid.method_24345()) {
            return false;
        }
        NPCState state = maid.getNpcState();
        class_1309 owner = this.maid.method_35057();
        if (owner == null || state != NPCStates.WORKING || maid.getWorkMode() != NPCWorkModes.BREED) {
            return false;
        }
        class_2338 workPos = maid.getWorkingPos();
        class_3218 serverWorld = method_64451(maid);

        List<class_1429> targets = this.field_6660.method_37908().method_8390(class_1429.class, new class_238(workPos).method_1009(16, 8, 16), (e) -> {
            boolean alive = e.method_5805();
            boolean hasItem = e.method_6481(this.maid.method_5998(class_1268.field_5808));
            int i = e.method_5618();
            if (i == 0 && e.method_6482() && !e.method_6109()) {
                return alive && hasItem;
            }
            return false;
        });
        this.targetEntity = serverWorld.method_64393(targets, this.targetPredicate, this.maid, this.maid.method_23317(), this.maid.method_23320(), this.maid.method_23321());
        return this.targetEntity != null;
    }

    @Override
    public void method_6269() {
        this.task = ()-> {
            ((IAnimalEntity)this.targetEntity).eatStackFood(this.maid, class_1268.field_5808, this.maid.method_5998(class_1268.field_5808));
            this.targetEntity.method_61458();
            ((IAnimalEntity)this.targetEntity).loveEntity(this.maid);
        };
    }

    @Override
    public void method_6268() {
        if (this.task == null) {
            return;
        }
        if (this.targetEntity != null && this.targetEntity.method_5805()) {
            this.maid.method_5942().method_6335(this.targetEntity, 1.0D);

            if (this.maid.method_5858(this.targetEntity) <= 4.0D) {
                this.task.run();
                this.task = null;
                this.method_6270();
            }
        }
    }

}
